@@ -3,7 +3,11 @@ module Main where
 
 import System.Environment        (getArgs)
 import System.Console.GetOpt
+import Data.List
 import Control.Monad
+import Filesystem.Path.CurrentOS hiding (concat, null)
+import Data.Text as T            hiding (foldl, concat, intercalate, null)
+import Prelude                   hiding (FilePath)
 import SOS
 
 main :: IO ()
@@ -24,7 +28,7 @@ defaultOptions :: Options
 defaultOptions = Options { optShowVersion = False
                          , optCommands    = []
                          , optPatterns    = []
-                         , optDirectory   = "."
+                         , optDirectory   = fromText $ T.pack "."
                          }
 
 options :: [OptDescr (Options -> Options)]
@@ -38,7 +42,7 @@ options = [ Option "v" ["version"]
               (ReqArg (\e opts -> opts { optPatterns = optPatterns opts ++ [e] }) "pattern")
               "Add pattern to match on file path."
           , Option "d" ["directory"]
-              (ReqArg (\d opts -> opts { optDirectory = d }) "directory")
+              (ReqArg (\d opts -> opts { optDirectory = decodeString d }) "directory")
               "Set directory to watch for changes (default is ./)."
           ]
 
@@ -46,7 +50,7 @@ header :: String
 header = "Usage: sos [vb] -c command -p pattern"
 
 version :: String
-version = "\nSteel Overseer 1.1.0.4\n"
+version = "\nSteel Overseer 1.1.0.0\n"
 
 startWithOpts :: Options -> IO ()
 startWithOpts opts = do
